dfw.beer.survey: Dallas-Forth Worth beer and brewery survey (autumn/winter...

Description Usage Format

Description

These data were created because Derek was bored and loves beer. See <http://www.dallasobserver.com/restaurants/dfws-favorite-local-beer-as-proven-by-an-actual-scientist-7024953> and <http://www.derekbeaton.com/dallass-favorite-beers/>

Usage

1

Format

A list with two items:

original

A list with many items exported from Google Sheets. Contains information on respondents and beers for the survey.

mca.ex

A list with three items that are the prepare data (for use with multiple correspondence analysis or similar technique)


derekbeaton/ExPositionData documentation built on April 8, 2020, 4:55 p.m.