These data were created because Derek was bored and loves beer. See <http://www.dallasobserver.com/restaurants/dfws-favorite-local-beer-as-proven-by-an-actual-scientist-7024953> and <http://www.derekbeaton.com/dallass-favorite-beers/>
1 |
A list with two items:
A list with many items exported from Google Sheets. Contains information on respondents and beers for the survey.
A list with three items that are the prepare data (for use with multiple correspondence analysis or similar technique)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.